@@ -78,9 +78,9 @@ class FieldValueThroughInlineAdmin(admin.TabularInline):
 
 @admin.register(Field)
 class FieldAdmin(admin.ModelAdmin):
-    list_display = ['id', 'name', 'genre', 'is_active', 'is_required', 'created_at', 'updated_at']
+    list_display = ['id', 'name', 'genre', 'is_active', 'created_at', 'updated_at']
     list_display_links = ['id', 'name']
-    list_editable = ['is_active', 'is_required']
+    list_editable = ['is_active']
     list_filter = ['is_active', 'created_at', 'genre']
     search_fields = ['label', 'name', 'forms__title']
     inlines = [FieldValueThroughInlineAdmin]
