@@ -1,6 +1,7 @@
 import uuid
 from django.db import models
 from django.core.validators import RegexValidator
+from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.core.cache import cache
@@ -13,7 +14,8 @@ from django_form_generator.common.utils import (
 )
 
 from django_form_generator import const
-from django_form_generator.managers import FormManager
+from django_form_generator.settings import form_generator_settings as fg_settings
+
 
 
 CONTENT_TYPE_MODELS_LIMIT = models.Q(
@@ -104,7 +106,7 @@ class Form(BaseModel):
     )
     is_editable = models.BooleanField(_("Is Editable"), default=False)
 
-    objects: FormManager = FormManager()
+    objects = fg_settings.FORM_MANAGER() #type: ignore
 
     class Meta:
         verbose_name = _("Form")
@@ -119,6 +121,9 @@ class Form(BaseModel):
     def __str__(self) -> str:
         return self.title
 
+    def get_absolute_url(self):
+        return reverse("django_form_generator:form_detail", kwargs={"pk": self.pk})
+
     def __call_apis(
         self, execute_time: const.FormAPIManagerExecuteTime, response_data: dict
     ):
@@ -288,7 +293,7 @@ class Field(BaseModel):
             "help_text": self.help_text,
             "label": self.label,
         }
-        
+
         if self.error_message:
             attrs.update({"error_messages": {"Invalid": self.error_message}})
 
@@ -309,30 +314,28 @@ class Field(BaseModel):
         return attrs
 
     def build_widget_attrs(self, form, extra_attrs: dict | None = None):
+        attrs = {"instance_id": self.pk, "onchange": "onElementChange(this)"}
         form_field_through = self.form_field_through.filter(form_id=form.id).last()  # type: ignore
-        attrs = {"instance_id": self.pk,
-                "position": form_field_through.position}
 
-        if self.genre in const.FieldGenre.selectable_fields():
-            attrs.update({"onchange": "onElementChange(this)"})
-        else:
-            attrs.update({"onkeypress": "onElementChange(this)"})
-
-        if form_field_through.category is not None:
-            attrs.update({"category": form_field_through.category.title})
+        if self.content_object is not None:
+            attrs.update({"disabled": True})
 
         if self.content_object is not None:
             attrs.update(
                 {
                     "parent_object_id": self.object_id,
                     "parent_content_type": self.content_type.model,
-                    "disabled": True
                 }
             )
 
+        if form_field_through.category is not None:
+            attrs.update({"category": form_field_through.category.title})
+
         if self.placeholder is not None:
             attrs.update({"placeholder": self.placeholder})
 
+        attrs.update({"position": form_field_through.position})
+
         if extra_attrs:
             attrs.update(extra_attrs)
         return attrs
